Sphinx htmlslide sample
========================

* `sphinx-users.jp <http://sphinx-users.jp/>`_
* forked from:
   * http://jsdo.it/os0x/slide
   * http://jsdo.it/nabetama/k6lQ


What is this?
--------------
This presentation ware generated by:

* `Sphinx <http://sphinx.pocoo.org/>`_
* `sphinxjp.themes.htmlslide <http://pypi.python.org/pypi/sphinxjp.themes.htmlslide/>`_ plugin

Original Javascript codes are here:

* Original code: http://jsdo.it/os0x/slide
* Forked code: http://jsdo.it/nabetama/k6lQ

Presentation Environments
--------------------------
* HTML5 ready browsers
    * Chrome, Safari, and etc.

* Non HTML5 ready browsers
    * show slide but no-animation

Install
--------

install:

.. code-block:: bash

    $ easy_install sphinxjp.themes.htmlslide

setup your conf.py:

.. code-block:: python

    extensions = ['sphinxjp.themes.htmlslide']
    html_theme = 'htmlslide'
    pygments_style = 'monokai'

Rendering sample
-----------------

* unnumbered list
    1. numbered list
    2. http://sphinx-users.jp/

* **strong** , *emotion*
* `literal` , ``literal``
* :command:`command`

Rendering image
----------------

.. figure:: sphinxusers.jpg

    -- http://sphinx-users.jp/

reSt source for this slide
---------------------------

* `index.rst <_sources/index.txt>`_


